==> jc-1.4.0.tar.gz: java/io/StringReader.h <==
// public class java.io.StringReader

// class file dependencies
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 601164a45ef42ba9 java_io_StringReader
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_Reader

#include "java/io/Reader.h"

#ifndef _JC_java_io_StringReader_H_
#define _JC_java_io_StringReader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_StringReader$sub_refs	_jc_java_io_StringReader$sub_refs;
typedef struct _jc_java_io_StringReader$sub_nonrefs	_jc_java_io_StringReader$sub_nonrefs;
typedef struct _jc_java_io_StringReader$refs	_jc_java_io_StringReader$refs;
typedef struct _jc_java_io_StringReader$nonrefs	_jc_java_io_StringReader$nonrefs;
typedef struct _jc_java_io_StringReader$object	_jc_java_io_StringReader$object;

typedef const struct _jc_java_io_StringReader$vmethods	_jc_java_io_StringReader$vmethods;
typedef const struct _jc_java_io_StringReader$vtable	_jc_java_io_StringReader$vtable;
typedef const struct _jc_java_io_StringReader$vtype	_jc_java_io_StringReader$vtype;

// Constructors
extern void _jc_java_io_StringReader$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_StringReader$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_java_io_StringReader$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_StringReader$object *);
extern void _jc_java_io_StringReader$method$mark$422af117ab27d9db(_jc_env *, struct _jc_java_io_StringReader$object *, jint);
extern jboolean _jc_java_io_StringReader$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_java_io_StringReader$object *);
extern jint _jc_java_io_StringReader$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_StringReader$object *);
extern jint _jc_java_io_StringReader$method$read$146ad4b836c4a55b(_jc_env *, struct _jc_java_io_StringReader$object *, struct _jc_char_array *, jint, jint);
extern jboolean _jc_java_io_StringReader$method$ready$83ea616797d9c364(_jc_env *, struct _jc_java_io_StringReader$object *);
extern void _jc_java_io_StringReader$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_io_StringReader$object *);
extern jlong _jc_java_io_StringReader$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_io_StringReader$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_java_io_StringReader$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_StringReader$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_java_io_StringReader$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_java_io_StringReader$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_StringReader$method_info$read$146ad4b836c4a55b;
extern _jc_method _jc_java_io_StringReader$method_info$ready$83ea616797d9c364;
extern _jc_method _jc_java_io_StringReader$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_io_StringReader$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_io_StringReader$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_StringReader$object *);
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_java_io_StringReader$object *, jint);
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_java_io_StringReader$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_StringReader$object *);
	jint	(*read$146ad4b836c4a55b)(_jc_env *, struct _jc_java_io_StringReader$object *, struct _jc_char_array *, jint, jint);
	jboolean	(*ready$83ea616797d9c364)(_jc_env *, struct _jc_java_io_StringReader$object *);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_io_StringReader$object *);
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_io_StringReader$object *, jlong);
};

// Vtable
struct _jc_java_io_StringReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_StringReader$vmethods	java_io_StringReader;
};

// Vtype
struct _jc_java_io_StringReader$vtype {
	_jc_type			type;
	_jc_java_io_StringReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_StringReader$sub_refs {
	struct _jc_java_lang_String$object	*buf;
};

// Reference instance fields (object)
struct _jc_java_io_StringReader$refs {
    _jc_java_io_StringReader$sub_refs	java_io_StringReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_StringReader$sub_nonrefs {
	jint	pos;
	jint	markedPos;
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_java_io_StringReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_StringReader$sub_nonrefs	java_io_StringReader;
};

// Object instance structure
struct _jc_java_io_StringReader$object {
	_jc_java_io_StringReader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_StringReader$vtype	*vtype;
	_jc_java_io_StringReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_StringReader$vtype _jc_java_io_StringReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_StringReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_StringReader$class_object;

#endif	/* _JC_java_io_StringReader_H_ */

==> jc-1.4.6.tar.gz: java/io/StringReader.h <==
// public class java.io.StringReader

// class file dependencies
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 601164a45ef42ba9 java_io_StringReader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_Reader

#include "java/io/Reader.h"

#ifndef _JC_java_io_StringReader_H_
#define _JC_java_io_StringReader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_StringReader$sub_refs	_jc_java_io_StringReader$sub_refs;
typedef struct _jc_java_io_StringReader$sub_nonrefs	_jc_java_io_StringReader$sub_nonrefs;
typedef struct _jc_java_io_StringReader$refs	_jc_java_io_StringReader$refs;
typedef struct _jc_java_io_StringReader$nonrefs	_jc_java_io_StringReader$nonrefs;
typedef struct _jc_java_io_StringReader$object	_jc_java_io_StringReader$object;

typedef const struct _jc_java_io_StringReader$vmethods	_jc_java_io_StringReader$vmethods;
typedef const struct _jc_java_io_StringReader$vtable	_jc_java_io_StringReader$vtable;
typedef const struct _jc_java_io_StringReader$vtype	_jc_java_io_StringReader$vtype;

// Constructors
extern void _jc_java_io_StringReader$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_StringReader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_StringReader$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_StringReader$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_StringReader$method$mark$422af117ab27d9db(_jc_env *, struct _jc_java_io_StringReader$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_io_StringReader$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_java_io_StringReader$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_StringReader$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_StringReader$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_StringReader$method$read$146ad4b836c4a55b(_jc_env *, struct _jc_java_io_StringReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_io_StringReader$method$ready$83ea616797d9c364(_jc_env *, struct _jc_java_io_StringReader$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_StringReader$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_io_StringReader$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_io_StringReader$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_io_StringReader$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_StringReader$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_StringReader$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_java_io_StringReader$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_java_io_StringReader$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_StringReader$method_info$read$146ad4b836c4a55b;
extern _jc_method _jc_java_io_StringReader$method_info$ready$83ea616797d9c364;
extern _jc_method _jc_java_io_StringReader$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_io_StringReader$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_io_StringReader$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_StringReader$object *) _JC_JCNI_ATTR;
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_java_io_StringReader$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_java_io_StringReader$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_StringReader$object *) _JC_JCNI_ATTR;
	jint	(*read$146ad4b836c4a55b)(_jc_env *, struct _jc_java_io_StringReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
	jboolean	(*ready$83ea616797d9c364)(_jc_env *, struct _jc_java_io_StringReader$object *) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_io_StringReader$object *) _JC_JCNI_ATTR;
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_io_StringReader$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_StringReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_StringReader$vmethods	java_io_StringReader;
};

// Vtype
struct _jc_java_io_StringReader$vtype {
	_jc_type			type;
	_jc_java_io_StringReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_StringReader$sub_refs {
	struct _jc_java_lang_String$object	*buf;
};

// Reference instance fields (object)
struct _jc_java_io_StringReader$refs {
    _jc_java_io_StringReader$sub_refs	java_io_StringReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_StringReader$sub_nonrefs {
	jint	pos;
	jint	markedPos;
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_java_io_StringReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_StringReader$sub_nonrefs	java_io_StringReader;
};

// Object instance structure
struct _jc_java_io_StringReader$object {
	_jc_java_io_StringReader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_StringReader$vtype	*vtype;
	_jc_java_io_StringReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_StringReader$vtype _jc_java_io_StringReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_StringReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_StringReader$class_object;

#endif	/* _JC_java_io_StringReader_H_ */
